@@ -49,14 +49,25 @@ class F:
     """Object used for filtering entities
     before getting them from a repository."""
 
-    def __init__(self, type: FilterType, field: str, value: Any) -> None:
+    def __init__(
+        self, type: FilterType, field: str, value: Any, not_: bool = False
+    ) -> None:
         self.type = type
         self.field = field
         self.value = value
+        self.not_ = not_
 
     def __repr__(self) -> str:
         return f"F(type='{self.type}', field='{self.field}', value='{self.value}'')"
 
+    def __invert__(self) -> F:
+        return F(
+            type=self.type,
+            field=self.field,
+            value=self.value,
+            not_=True,
+        )
+
     @classmethod
     def eq(cls, field: str, value: Any) -> F:
         """Create a filter to find entities
@@ -276,7 +287,7 @@ class F:
         whose field is an IP address contained within
         a given subnet.
         """
-        return cls(FilterType.IPIN, field, value)
+        return cls(FilterType.IPIN, field, subnet)
 
     @classmethod
     def nipin(cls, field: str, subnet: str) -> F:
@@ -284,7 +295,7 @@ class F:
         whose field is an IP address not contained within
         a given subnet.
         """
-        return cls(FilterType.NIPIN, field, value)
+        return cls(FilterType.NIPIN, field, subnet)
 
     @classmethod
     def or_(cls, *filters: F) -> F:
@@ -300,6 +311,12 @@ class F:
         """
         return cls(FilterType.AND, "", filters)
 
+    def __or__(self, other: F) -> F:
+        return F.or_(self, other)
+
+    def __and__(self, other: F) -> F:
+        return F.and_(self, other)
+
 
 T = TypeVar("T")
 
